#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#***********************************************************************
#                                                                      *
# Program name  : frnxmill.oracle.sh                                   *
#                                                                      *
# Description   : Library Server database migration                    *
#                 from AIX DB2 DL V1 to AIX ORACLE DL V2               *
#                                                                      *
#***********************************************************************

#export FRNROOT=.

# Display copyright statement
cat copyright

# Setup message variables
#. ./frnxcosm.sh

user=`whoami`
if [[ $user != "oracle" ]]; then
   echo "Only the user oracle may perform database migration, exit."
   exit 1
fi # end of if current user is not oracle


# Prompt for oracle database name, userid and password
EXPDIR=`pwd`/exp
LOG=/tmp/migrate.log
cat /dev/null > $LOG
echo "Enter ORACLE database name: \c"
#dspmsg $MSG_MSGFILE $MSG_READDBNAME "$MSG_MSGNOTFOUND"
read dbname
if [[ -z "$dbname" ]]; then
   echo "Can not proceed without database name, exit"
   #dspmsg $MSG_MSGFILE $MSG_NODBNAME "$MSG_MSGNOTFOUND"
   exit 1
else
   typeset -u dbname
   export ORADB=$dbname
   export ORACLE_SID=$dbname
fi
echo "Enter database userid: \c"
   #dspmsg $MSG_MSGFILE $MSG_READUSERID "$MSG_MSGNOTFOUND"
read answer
if [[ -z "$answer" ]]; then
   echo "Can not proceed without userid, exit"
   #dspmsg $MSG_MSGFILE $MSG_NOUSERID "$MSG_MSGNOTFOUND"
   exit 1
else
   export ORAID=$answer
fi
echo "Enter database password: \c"
#dspmsg $MSG_MSGFILE $MSG_READPASSWD "$MSG_MSGNOTFOUND"
stty -echo
read answer
stty echo
echo
if [[ -z "$answer" ]]; then
   echo "Can not proceed without password, exit"
   #dspmsg $MSG_MSGFILE $MSG_NOPASSWORD "$MSG_MSGNOTFOUND"
   exit 1
else
   export ORAPWD=$answer
fi

echo "spool delrows.log;" > delrows.sql
echo "DELETE FROM AVT00002          ;" >> delrows.sql
echo "DELETE FROM AVT00003          ;" >> delrows.sql
echo "DELETE FROM AVT00004          ;" >> delrows.sql
echo "DELETE FROM AVT00005          ;" >> delrows.sql
echo "DELETE FROM AVT00006          ;" >> delrows.sql
echo "DELETE FROM AVT00007          ;" >> delrows.sql
echo "DELETE FROM SBTACCESSLIST     ;" >> delrows.sql
echo "DELETE FROM SBTCHECKEDOUT     ;" >> delrows.sql
echo "DELETE FROM SBTCLASSATTRS     ;" >> delrows.sql
echo "DELETE FROM SBTCNTL           ;" >> delrows.sql
echo "DELETE FROM SBTDESCRIPTIONS   ;" >> delrows.sql
echo "DELETE FROM SBTEVENTS         ;" >> delrows.sql
echo "DELETE FROM SBTFOREIGNPARTSNMS;" >> delrows.sql
echo "DELETE FROM SBTGRAVEYARD      ;" >> delrows.sql
echo "DELETE FROM SBTITEMS          ;" >> delrows.sql
echo "DELETE FROM SBTLICENSEKEY     ;" >> delrows.sql
echo "DELETE FROM SBTLICVIOLATIONS  ;" >> delrows.sql
echo "DELETE FROM SBTLINKS          ;" >> delrows.sql
echo "DELETE FROM SBTNAMES          ;" >> delrows.sql
echo "DELETE FROM SBTNLSKEYWORDS    ;" >> delrows.sql
echo "DELETE FROM SBTNLSLANGUAGES   ;" >> delrows.sql
echo "DELETE FROM SBTPARTS          ;" >> delrows.sql
echo "DELETE FROM SBTPATRONGROUP    ;" >> delrows.sql
echo "DELETE FROM SBTPATRONS        ;" >> delrows.sql
echo "DELETE FROM SBTPRIVILEGES     ;" >> delrows.sql
echo "DELETE FROM SBTPROPERTIES     ;" >> delrows.sql
echo "DELETE FROM SBTSBTABLES       ;" >> delrows.sql
echo "DELETE FROM SBTSTATICQUERIES  ;" >> delrows.sql
echo "DELETE FROM SBTVIEWATTRS      ;" >> delrows.sql
echo "DELETE FROM SBTVIEWDEFS       ;" >> delrows.sql
echo "DELETE FROM SBTWIPITEMS       ;" >> delrows.sql
echo "DELETE FROM SBTWIPSUSPITEMS   ;" >> delrows.sql

echo "DELETE FROM SBTCLASSDEFS      ;" >> delrows.sql
echo "DELETE FROM SBTQUERYEXPRS     ;" >> delrows.sql

echo "DELETE FROM SBTATTRDEFS       ;" >> delrows.sql
echo "DELETE FROM SBTCOLLNAME       ;" >> delrows.sql
echo "DELETE FROM SBTOBJECTSERVER   ;" >> delrows.sql
echo "DELETE FROM SBTACCESSCODES    ;" >> delrows.sql

echo "DELETE FROM ICV00002 ;" >> delrows.sql
echo "DELETE FROM ICV00003 ;" >> delrows.sql
echo "DELETE FROM ICV00004 ;" >> delrows.sql
echo "DELETE FROM ICV00005 ;" >> delrows.sql
echo "DELETE FROM ICV00006 ;" >> delrows.sql
echo "DELETE FROM ICV00007 ;" >> delrows.sql
echo "drop table AVT00001;" >> delrows.sql
echo "drop view ICV00001;" >> delrows.sql
echo "drop table AVT00008;" >> delrows.sql
echo "drop view ICV00008;" >> delrows.sql
echo "drop table AVT00009;" >> delrows.sql
echo "drop view ICV00009;" >> delrows.sql
echo "drop table AVT00010;" >> delrows.sql
echo "drop view ICV00010;" >> delrows.sql
echo "drop table AVT00011;" >> delrows.sql
echo "drop view ICV00011;" >> delrows.sql
echo "drop table AVT00012;" >> delrows.sql
echo "drop view ICV00012;" >> delrows.sql
echo "CREATE TABLE AVT00001 (ITEMID           CHAR(16)           NOT NULL," >> delrows.sql
echo "                       ATTRIBUTE00001   NUMBER(5,0)        NOT NULL," >> delrows.sql
echo "                       ATTRIBUTE00002   CHAR(8)            NOT NULL," >> delrows.sql
echo "                       ATTRIBUTE00003   VARCHAR(40)); " >> delrows.sql

echo "CREATE UNIQUE INDEX AVT1INDX ON AVT00001" >> delrows.sql
echo "                 ( ITEMID    ASC )" >> delrows.sql
echo "                 TABLESPACE objndx;" >> delrows.sql

echo "CREATE UNIQUE INDEX SBUXAVT0000101 ON AVT00001" >> delrows.sql
echo "                 ( ATTRIBUTE00001    ASC )" >> delrows.sql
echo "                 TABLESPACE objndx;" >> delrows.sql

echo "spool off;" >> delrows.sql

svrmgrl<<-EOF
connect $ORAID/$ORAPWD
@delrows.sql
exit;
EOF
cnt=`grep "ORA-" delrows.log|wc -l`

#check if data deleted successfully 
if (( $cnt != 0 )); then
   echo "Error occurred while deleting sample data, see delrows.log"
   exit 1
fi

if [[ -f $EXPDIR/create.oratbl.sql ]]; then
   TBLFN=$EXPDIR/create.oratbl.sql
else
   if [[ -f $EXPDIR/frncrttb.bat ]]; then
      TBLFN=$EXPDIR/frncrttb.bat
   else
      echo "Error occurred, could not find create.oratbl.sql or frncrttb.bat"
      exit 1
   fi
fi
tot=`grep "CREATE" $TBLFN|wc -l`
if (( tot > 0 )); then
create_msg=`svrmgrl<<-EOF
connect $ORAID/$ORAPWD
spool $LOG
@$TBLFN
exit;
EOF`
#  ora_err=`echo $create_msg | grep "ORA" | wc -l`
   ora_err=`echo $LOG| grep "ORA" | wc -l`
   if (( ora_err == 0 )); then #create tables successfully
      echo "Create tables successfully."
      #dspmsg $MSG_MSGFILE $MSG_TBCREATEOK "$MSG_MSGNOTFOUND"
   else
      oraresult=`echo $LOG| grep "ORA"`
      echo "Error creating tables.  Return code=$oraresult"
      #dspmsg $MSG_MSGFILE $MSG_TBCREATEERROR "$MSG_MSGNOTFOUND" "$oraresult"
      exit 1
   fi #end of create tables successfully
fi
echo "Load data into database tables, please wait ..."
#dspmsg $MSG_MSGFILE $MSG_LOADINGDATA "$MSG_MSGNOTFOUND"
#. .$EXPDIR/load.sql $ORAID $ORAPWD $EXPDIR >> $LOG
. $EXPDIR/load.sql $ORAID $ORAPWD >> $LOG
if [[ $? -eq 0 ]]; then #create tables successfully
   echo "Load data into $ORADB successfully."
   #dspmsg $MSG_MSGFILE $MSG_TBLLOADOK "$MSG_MSGNOTFOUND"
svrmgrl<<-EOF
connect $ORAID/$ORAPWD
update sbtclassdefs set dllstatus=-1 where classid>0;
update sbtviewdefs set dllstatus=1;
exit;
EOF
   echo "Please see $LOG for migration information"
   echo "Also, check $EXPDIR/*.log for sqlloader info"
   #dspmsg $MSG_MSGFILE $MSG_CHECKLOG2 "$MSG_MSGNOTFOUND" "$LOG" "$EXPDIR"

   `pwd`/frnxmilt.oracle.exe $ORADB $ORAID $ORAPWD
   if [[ $? -ne 0 ]];then
      echo "\nfailed during frnxmilt.oracle.exe"
   fi
else
   echo "Load data failed.  Return code=$?"
   #dspmsg $MSG_MSGFILE $MSG_TBLLOADERROR "$MSG_MSGNOTFOUND" "$?"
fi

